@@ -21,7 +21,7 @@ setup(
     },
     author="SQLShell Team",
     description="A powerful SQL shell with GUI interface for data analysis",
-    long_description=open('README.md').read(),
+    long_description=open('README.md', encoding='utf-8').read(),
     long_description_content_type="text/markdown",
     keywords="sql, data analysis, gui, duckdb",
     url="https://github.com/yourusername/sqlshell",
